======================
Neural Network Figures
======================

Draw neural network figures with Matplotlib

Note:

    This project is in beta stage, the API may change.

Contents:

.. toctree::
   :maxdepth: 2

   intro
   API <api>
   developer

* Web site: https://gitlab.com/jdhp-dev/neural-network-figures
* Online documentation: https://jdhp-dev.gitlab.io/neural-network-figures
* Source code: https://gitlab.com/jdhp-dev/neural-network-figures
* Issue tracker: https://gitlab.com/jdhp-dev/neural-network-figures/issues
* Pytest code coverage: https://jdhp-dev.gitlab.io/neural-network-figures/htmlcov/index.html
* Neural Network Figures on PyPI: https://pypi.org/project/nnfigs

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Credits
=======

.. include:: ../AUTHORS
   :literal:

License
=======

.. highlight:: none

.. include:: ../LICENSE
   :literal: